==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/tetopologiesaugment/te/templates/LinkTemplateKeys.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tetopologiesaugment.te.templates;

import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.TeTemplateName;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of linkTemplate.
 */
public class LinkTemplateKeys implements KeyInfo<DefaultLinkTemplate> {
    protected TeTemplateName name;
    /**
     * Returns the attribute name.
     *
     * @return name value of name
     */
    public TeTemplateName name() {
        return name;
    }

    /**
     * Sets the value to attribute name.
     *
     * @param name value of name
     */
    public void name(TeTemplateName name) {
        this.name = name;
    }


    @Override
    public int hashCode() {
        return Objects.hash(name);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof LinkTemplateKeys) {
            LinkTemplateKeys other = (LinkTemplateKeys) obj;
            return
                Objects.equals(name, other.name);
        }
        return false;
    }
}

==> onos-yang-runtime-2.4-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/tetopologiesaugment/te/templates/LinkTemplateKeys.java <==
/*
 * Copyright 2018-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.tetopologiesaugment.te.templates;

import org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.TeTemplateName;
import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of linkTemplate.
 */
public class LinkTemplateKeys implements KeyInfo<DefaultLinkTemplate> {
    protected TeTemplateName name;
    /**
     * Returns the attribute name.
     *
     * @return name value of name
     */
    public TeTemplateName name() {
        return name;
    }

    /**
     * Sets the value to attribute name.
     *
     * @param name value of name
     */
    public void name(TeTemplateName name) {
        this.name = name;
    }


    @Override
    public int hashCode() {
        return Objects.hash(name);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof LinkTemplateKeys) {
            LinkTemplateKeys other = (LinkTemplateKeys) obj;
            return
                Objects.deepEquals(name, other.name);
        }
        return false;
    }
}
